@@ -3,9 +3,9 @@
 # Released under the GNU Lesser General Public License, version 3 or later.
 # See the files COPYING and COPYING.LESSER for details.
 
-"""
-:mod:`gridData` -- Handling grids of data
-=========================================
+r"""
+Handling grids of data --- :mod:`gridData`
+==========================================
 
 Overview
 --------
@@ -18,9 +18,10 @@ we also store the edges, which are are (essentially) the cartesian
 coordinates of the intersections of the grid (mesh) lines on the
 axes. In this way the grid is anchored in space.
 
-The :class:`~gridData.core.Grid` object can be resampled at arbitrary resolution (by
-interpolating the data). Standard algebraic operations are defined for
-grids on a point-wise basis (same as for :class:`numpy.ndarray`).
+The :class:`~gridData.core.Grid` object can be resampled at arbitrary
+resolution (by interpolating the data). Standard algebraic operations
+are defined for grids on a point-wise basis (same as for
+:class:`numpy.ndarray`).
 
 
 Description
@@ -44,25 +45,26 @@ This is equivalent to knowing
 
 :class:`~gridData.core.Grid` objects have some convenient properties:
 
-* The data is represented as a :class:`numpy.ndarray` and thus shares
-  all the advantages coming with this sophisticated and powerful
-  library.
+* The data is represented as a :class:`numpy.ndarray` in
+  :attr:`Grid.grid<~gridData.core.Grid.grid>` and thus can be directly
+  manipulated with all the tools available in NumPy.
 
-* They can be manipulated arithmetically, e.g. one can simply add or
-  subtract two of them and get another one, or multiply by a
-  constant. Note that all operations are defined point-wise (see the
-  :mod:`numpy` documentation for details) and that only grids defined
-  on the same cell edges can be combined.
+* :class:`Grid` instances can be manipulated arithmetically, e.g. one
+  can simply add or subtract two of them and get another one, or
+  multiply by a constant. Note that all operations are defined
+  point-wise (see the :mod:`numpy` documentation for details) and that
+  only grids defined on the same cell edges can be combined.
 
-* A :class:`~gridData.core.Grid` object can also be created from within python code
-  e.g. from the output of the :func:`numpy.histogramdd` function.
+* A :class:`~gridData.core.Grid` object can also be created from
+  within python code e.g. from the output of the
+  :func:`numpy.histogramdd` function.
 
 * The representation of the data is abstracted from the format that
   the files are saved in. This makes it straightforward to add
   additional readers for new formats.
 
 * The data can be written out again in formats that are understood by
-  other programs such as VMD or PyMOL.
+  other programs such as VMD_, ChimeraX_ or PyMOL_.
 
 
 Reading grid data files
@@ -93,27 +95,24 @@ See the doc string for :class:`~gridData.core.Grid` for details.
 Formats
 -------
 
-The following formats are available (:ref:`supported-file-formats`):
+For the available file formats see :ref:`supported-file-formats`.
 
-   :mod:`~gridData.OpenDX`
-        IBM's Data Explorer, http://www.opendx.org/
-   :mod:`~gridData.gOpenMol`
-        http://www.csc.fi/gopenmol/
-   :mod:`~gridData.CCP4`
-        CCP4 format http://www.ccp4.ac.uk/html/maplib.html#description
-   pickle
-        python pickle file (:mod:`pickle`)
 
+.. _VMD: https://www.ks.uiuc.edu/Research/vmd/
+
+.. _PyMOL: https://pymol.org/
+
+.. _ChimeraX: https://www.cgl.ucsf.edu/chimerax/
 
 """
 
 from .core import Grid
 from . import OpenDX
 from . import gOpenMol
-from . import CCP4
-from . import testing
+from . import mrc
+from . import CCP4  # remove in 1.0.0
 
-__all__ = ['Grid', 'OpenDX', 'gOpenMol', 'CCP4', 'testing']
+__all__ = ['Grid', 'OpenDX', 'gOpenMol', 'mrc', 'CCP4']
 
 from ._version import get_versions
 __version__ = get_versions()['version']
