@@ -1,8 +1,8 @@
 # gridDataFormats --- python modules to read and write gridded data
 # Copyright (c) 2009-2014 Oliver Beckstein <orbeckst@gmail.com>
 # Released under the GNU Lesser General Public License, version 3 or later.
-"""
-:mod:`gridData.core` --- Core functionality for storing n-D grids
+r"""
+Core functionality for storing n-D grids --- :mod:`gridData.core`
 =================================================================
 
 The :mod:`core` module contains classes and functions that are
@@ -40,7 +40,7 @@ import numpy
 
 from . import OpenDX
 from . import gOpenMol
-from . import CCP4
+from . import mrc
 
 
 def _grid(x):
@@ -52,70 +52,158 @@ def _grid(x):
 
 
 class Grid(object):
-    """Class to manage a multidimensional grid object.
+    """A multidimensional grid object with origin and grid spacings.
 
-    The export(format='dx') method always exports a 3D object, the
-    rest should work for an array of any dimension.
+    :class:`Grid` objects can be used in arithmetical calculations
+    just like numpy arrays *if* they are compatible, i.e., they have
+    the same shapes and lengths. In order to make arrays compatible,
+    they an be resampled (:meth:`resample`) on a common grid.
 
-    The grid (Grid.grid) can be manipulated as a standard numpy
-    array.
+    The attribute :attr:`grid` that holds the data is a standard numpy
+    array and so the data can be directly manipulated.
+
+    Data can be read from a number of molecular volume/density formats
+    and written out in different formats with :meth:`export`.
+
+
+    Parameters
+    ----------
+    grid : numpy.ndarray or str (optional)
+      Build the grid either from a histogram or density (a numpy nD
+      array) or read data from a filename.
+
+    edges : list (optional)
+      List of arrays, the lower and upper bin edges along the axes
+      (same as the output by :func:`numpy.histogramdd`)
+
+    origin : :class:`numpy.ndarray` (optional)
+      Cartesian coordinates of the center of grid position at index
+      ``[0, 0, ..., 0]``.
+
+    delta : :class:`numpy.ndarray` (optional)
+      Either ``n x n`` array containing the cell lengths in each dimension,
+      or ``n x 1`` array for rectangular arrays.
+
+    metadata : dict (optional)
+      A user defined dictionary of arbitrary key/value pairs
+      associated with the density; the class does not touch
+      :attr:`metadata` but stores it with :meth:`save`
+
+    interpolation_spline_order : int (optional)
+      Order of interpolation function for resampling with
+      :func:`resample`; cubic splines = 3 and the default is 3
+
+    file_format : str (optional)
+      Name of the file format; only necessary when `grid` is a
+      filename (see :meth:`load`) and autodetection of the file
+      format fails. The default is ``None`` and normally the file
+      format is guessed from the file extension.
+
+    Raises
+    ------
+    TypeError
+      If the dimensions of the various input data do not agree with
+      each other.
+    ValueError
+      If some of the required data are not provided in the keyword
+      arguments, e.g., if only the `grid` is supplied as an array but
+      not the `edges` or only `grid` and one of `origin` and `delta`.
+    NotImplementedError
+      If triclinic (non-orthorhombic) boxes are supplied in `delta`
+
+      .. Note:: `delta` can only be a 1D array of length :attr:`grid.ndim`
+
+
+    Attributes
+    ----------
+    grid : :class:`numpy.ndarray`
+      This array can be any number of dimensions supported by NumPy
+      in order to represent high-dimensional data. When used with
+      data that represents real space densities then the **axis
+      convention in GridDataFormats** is that axis 0 corresponds to
+      the Cartesian :math:`x` component, axis 1 corresponds to the
+      :math:`y` component, and axis 2 to the :math:`z` component.
+
+    delta : :class:`numpy.ndarray`
+      Length of a grid cell (spacing or voxelsize) in :math:`x`,
+      :math:`y`, :math:`z` dimensions. This is a *1D array* with
+      length :attr:`Grid.grid.ndim`.
+
+    origin : :class:`numpy.ndarray`
+      Array with the Cartesian coordinates of the coordinate system
+      origin, the *center* of cell ``Grid.grid[0, 0, .., 0]``.
+
+    edges : list
+      List of arrays, one for each axis in :attr:`grid`.  Each 1D edge
+      array describes the *edges* of the grid cells along the
+      corresponding axis. The length of an edge array for axis ``i``
+      is ``grid.shape[i] + 1`` because it contains the lower boundary
+      for the first cell, the boundaries between all grid cells, and
+      the upper boundary for the last cell. The edges are assumed to
+      be regular with spacing indicated in :attr:`delta`, namely
+      ``Grid.delta[i]`` for axis ``i``.
+
+    midpoints : list
+      List of arrays, one for each axis in :attr:`grid`.  Each 1D
+      midpoints array contains the *midpoints* of the grid cells along
+      the corresponding axis.
+
+    metadata : dict
+      A user-defined dictionary that can be used to annotate the
+      data. The content is not touched by :class:`Grid`. It is saved
+      together with the other data with :meth:`save`.
+
+
+    Example
+    -------
+    Create a Grid object from data.
+
+    From :func:`numpy.histogramdd`::
+
+      grid, edges = numpy.histogramdd(...)
+      g = Grid(grid, edges=edges)
+
+    From an arbitrary grid::
+
+      g = Grid(grid, origin=origin, delta=delta)
+
+    From a saved file::
+
+      g = Grid(filename)
+
+    or ::
+
+      g = Grid()
+      g.load(filename)
+
+
+    Notes
+    -----
+    In principle, the dimension (number of axes) is arbitrary but in
+    practice many formats only support three and almost all
+    functionality is only tested for this special case.
+
+    The :meth:`export` method with ``format='dx'`` always exports a 3D
+    object. Other methods might work for an array of any dimension (in
+    particular the Python pickle output).
+
+
+    .. versionchanged:: 0.5.0
+       New *file_format* keyword argument.
+
+    .. versionchanged:: 0.7.0
+       CCP4 files are now read with :class:`gridData.mrc.MRC` and not anymore
+       with the deprecated/buggy `ccp4.CCP4`
 
-    The attribute Grid.metadata holds a user-defined dictionary that
-    can be used to annotate the data. It is saved with save().
     """
+
+    #: Default format for exporting with :meth:`export`.
     default_format = 'DX'
 
     def __init__(self, grid=None, edges=None, origin=None, delta=None,
-                 metadata={}, interpolation_spline_order=3,
+                 metadata=None, interpolation_spline_order=3,
                  file_format=None):
-        """
-        Create a Grid object from data.
-
-        From a numpy.histogramdd()::
-
-          grid,edges = numpy.histogramdd(...)
-          g = Grid(grid,edges=edges)
-
-        From an arbitrary grid::
-
-          g = Grid(grid,origin=origin,delta=delta)
-
-        From a saved file::
-
-          g = Grid(filename)
-
-        or ::
-
-          g = Grid()
-          g.load(filename)
-
-        :Arguments:
-          grid
-            histogram or density, defined on numpy nD array, or filename
-          edges
-            list of arrays, the lower and upper bin edges along the axes
-            (both are output by numpy.histogramdd())
-          origin
-            cartesian coordinates of the center of grid[0,0,...,0]
-          delta
-            Either n x n array containing the cell lengths in each dimension,
-            or n x 1 array for rectangular arrays.
-          metadata
-            a user defined dictionary of arbitrary values
-            associated with the density; the class does not touch
-            metadata[] but stores it with save()
-          interpolation_spline_order
-            order of interpolation function for resampling; cubic splines = 3 [3]
-          file_format
-             file format; only necessary when ``grid`` is a filename (see :meth:`Grid.load`);
-             default is ``None`` and the file format is autodetected.
-
-
-        .. versionchanged:: 0.5.0
-           New *file_format* keyword argument.
-
-        """
-        # file formats are guess from extension == lower case key
+        # file formats are guessed from extension == lower case key
         self._exporters = {
             'DX': self._export_dx,
             'PKL': self._export_python,
@@ -123,7 +211,8 @@ class Grid(object):
             'PYTHON': self._export_python,  # compatibility
         }
         self._loaders = {
-            'CCP4': self._load_cpp4,
+            'CCP4': self._load_mrc,
+            'MRC':  self._load_mrc,
             'DX': self._load_dx,
             'PLT': self._load_plt,
             'PKL': self._load_python,
@@ -131,7 +220,7 @@ class Grid(object):
             'PYTHON': self._load_python,  # compatibility
         }
 
-        self.metadata = metadata
+        self.metadata = metadata if metadata is not None else {}
         self.__interpolated = None  # cache for interpolated grid
         self.__interpolation_spline_order = interpolation_spline_order
         self.interpolation_cval = None  # default to using min(grid)
@@ -157,38 +246,7 @@ class Grid(object):
             if filename is not None:
                 self.load(filename, file_format=file_format)
             else:
-                if edges is not None:
-                    # set up from histogramdd-type data
-                    self.grid = numpy.asanyarray(grid)
-                    self.edges = edges
-                    self._update()
-                elif origin is not None and delta is not None:
-                    # setup from generic data
-                    origin = numpy.asanyarray(origin)
-                    delta = numpy.asanyarray(delta)
-                    if len(origin) != grid.ndim:
-                        raise TypeError(
-                            "Dimension of origin is not the same as grid dimension.")
-                    if delta.shape == () and numpy.isreal(delta):
-                        delta = numpy.ones(grid.ndim) * delta
-                    elif delta.ndim > 1:
-                        raise NotImplementedError(
-                            "Non-rectangular grids are not supported.")
-                    elif len(delta) != grid.ndim:
-                        raise TypeError("delta should be scalar or array-like of"
-                                        "len(grid.ndim)")
-                    # note that origin is CENTER so edges must be shifted by -0.5*delta
-                    self.edges = [origin[dim] +
-                                  (numpy.arange(m + 1) - 0.5) * delta[dim]
-                                  for dim, m in enumerate(grid.shape)]
-                    self.grid = numpy.asanyarray(grid)
-                    self._update()
-                else:
-                    raise ValueError("Wrong/missing data to set up Grid. Use Grid() or "
-                                     "Grid(grid=<array>, edges=<list>) or "
-                                     "Grid(grid=<array>, origin=(x0, y0, z0), delta=(dx, dy, dz)):\n"
-                                     "grid={0} edges={1} origin={2} delta={3}".format(
-                                         grid, edges, origin, delta))
+                self._load(grid, edges, metadata, origin, delta)
 
     @property
     def interpolation_spline_order(self):
@@ -218,12 +276,11 @@ class Grid(object):
         self.__interpolation_spline_order = x
         self._update()
 
-
     def resample(self, edges):
         """Resample data to a new grid with edges *edges*.
 
         This method creates a new grid with the data from the current
-        grid resampled to a regular grid specified by *edges*.  The
+        grid resampled to a regular grid specified by `edges`.  The
         order of the interpolation is set by
         :attr:`Grid.interpolation_spline_order`: change the value
         *before* calling :meth:`resample`.
@@ -244,7 +301,7 @@ class Grid(object):
         Examples
         --------
 
-        Providing *edges* (a tuple of three arrays, indicating the
+        Providing `edges` (a tuple of three arrays, indicating the
         boundaries of each grid cell)::
 
           g = grid.resample(edges)
@@ -276,24 +333,47 @@ class Grid(object):
         factor : float
             The number of grid cells are scaled with `factor` in each
             dimension, i.e., ``factor * N_i`` cells along each
-            dimension i.
+            dimension i. Must be positive, and cannot result in fewer
+            than 2 cells along a dimension.
 
 
         Returns
         -------
-        Grid
-
+        interpolated grid : Grid
+            The resampled data are represented on a :class:`Grid` with the new
+            grid cell sizes.
 
         See Also
         --------
         resample
 
+
+        .. versionchanged:: 0.6.0
+           Previous implementations would not alter the range of the grid edges
+           being resampled on. As a result, values at the grid edges would creep
+           steadily inward. The new implementation recalculates the extent of
+           grid edges for every resampling.
+
         """
-        # new number of edges N' = (N-1)*f + 1
-        newlengths = [(N - 1) * float(factor) + 1 for N in self._len_edges()]
-        edges = [numpy.linspace(start, stop, num=int(N), endpoint=True)
-                 for (start, stop, N) in
-                 zip(self._min_edges(), self._max_edges(), newlengths)]
+        if float(factor) <= 0:
+            raise ValueError("Factor must be positive")
+        # Determine current spacing
+        spacing = (numpy.array(self._max_edges()) - numpy.array(self._min_edges())) / (
+                  -1 + numpy.array(self._len_edges()))
+        # First guess at the new spacing is inversely related to the
+        # magnification factor.
+        newspacing = spacing / float(factor)
+        smidpoints = numpy.array(self._midpoints())
+        # We require that the new spacing result in an even subdivision of the
+        # existing midpoints
+        newspacing = (smidpoints[:, -1] - smidpoints[:, 0]) / (numpy.maximum(
+            1, numpy.floor((smidpoints[:, -1] - smidpoints[:, 0]) / newspacing)))
+        # How many edge points should there be? It is the number of intervals
+        # between midpoints + 2
+        edgelength = 2 + \
+            numpy.round((smidpoints[:, -1] - smidpoints[:, 0]) / newspacing)
+        edges = [numpy.linspace(start, stop, num=int(N), endpoint=True) for (start, stop, N) in zip(
+            smidpoints[:, 0] - 0.5 * newspacing, smidpoints[:, -1] + 0.5 * newspacing, edgelength)]
         return self.resample(edges)
 
     def _update(self):
@@ -352,6 +432,19 @@ class Grid(object):
         a cubic spline interpolation can generate negative values,
         especially at the boundary between 0 and high values.
 
+        Internally, the function uses :func:`scipy.ndimage.map_coordinates`
+        with ``mode="constant"`` whereby interpolated values outside
+        the interpolated grid are determined by filling all values beyond
+        the edge with the same constant value, defined by the
+        :attr:`interpolation_cval` parameter, which when not set defaults
+        to the minimum value in the interpolated grid.
+
+
+        .. versionchanged:: 0.6.0
+           Interpolation outside the grid is now performed with
+           ``mode="constant"`` rather than ``mode="nearest"``, eliminating
+           extruded volumes when interpolating beyond the grid.
+
         """
         if self.__interpolated is None:
             self.__interpolated = self._interpolationFunctionFactory()
@@ -380,7 +473,11 @@ class Grid(object):
         else:
             available = self._loaders
         if file_format is None:
-            file_format = os.path.splitext(filename)[1][1:]
+            splitted = os.path.splitext(filename)
+            if splitted[1][1:] in ('gz', ):
+                file_format = os.path.splitext(splitted[0])[1][1:]
+            else:
+                file_format = splitted[1][1:]
         file_format = file_format.upper()
         if not file_format:
             file_format = self.default_format
@@ -400,13 +497,51 @@ class Grid(object):
                                                 file_format=file_format,
                                                 export=False)]
 
+    def _load(
+            self,
+            grid=None,
+            edges=None,
+            metadata=None,
+            origin=None,
+            delta=None):
+        if edges is not None:
+            # set up from histogramdd-type data
+            self.grid = numpy.asanyarray(grid)
+            self.edges = edges
+            self._update()
+        elif origin is not None and delta is not None:
+            # setup from generic data
+            origin = numpy.asanyarray(origin)
+            delta = numpy.asanyarray(delta)
+            if len(origin) != grid.ndim:
+                raise TypeError(
+                    "Dimension of origin is not the same as grid dimension.")
+            if delta.shape == () and numpy.isreal(delta):
+                delta = numpy.ones(grid.ndim) * delta
+            elif delta.ndim > 1:
+                raise NotImplementedError(
+                    "Non-rectangular grids are not supported.")
+            elif len(delta) != grid.ndim:
+                raise TypeError("delta should be scalar or array-like of"
+                                "len(grid.ndim)")
+            # note that origin is CENTER so edges must be shifted by -0.5*delta
+            self.edges = [origin[dim] +
+                          (numpy.arange(m + 1) - 0.5) * delta[dim]
+                          for dim, m in enumerate(grid.shape)]
+            self.grid = numpy.asanyarray(grid)
+            self._update()
+        else:
+            raise ValueError(
+                "Wrong/missing data to set up Grid. Use Grid() or "
+                "Grid(grid=<array>, edges=<list>) or "
+                "Grid(grid=<array>, origin=(x0, y0, z0), delta=(dx, dy, dz)):\n"
+                "grid={0} edges={1} origin={2} delta={3}".format(
+                    grid, edges, origin, delta))
+
     def load(self, filename, file_format=None):
-        """Load saved (pickled or dx) grid and edges from <filename>.pickle
+        """Load saved grid and edges from `filename`
 
-           Grid.load(<filename>.pickle)
-           Grid.load(<filename>.dx)
-
-        The load() method calls the class's constructor method and
+        The :meth:`load` method calls the class's constructor method and
         completely resets all values, based on the loaded data.
         """
         filename = str(filename)
@@ -421,38 +556,40 @@ class Grid(object):
     def _load_python(self, filename):
         with open(filename, 'rb') as f:
             saved = cPickle.load(f)
-        self.__init__(grid=saved['grid'],
-                      edges=saved['edges'],
-                      metadata=saved['metadata'])
+        self._load(grid=saved['grid'],
+                   edges=saved['edges'],
+                   metadata=saved['metadata'])
 
-    def _load_cpp4(self, filename):
-        """Initializes Grid from a CCP4 file."""
-        ccp4 = CCP4.CCP4()
-        ccp4.read(filename)
-        grid, edges = ccp4.histogramdd()
-        self.__init__(grid=grid, edges=edges, metadata=self.metadata)
+    def _load_mrc(self, filename):
+        """Initializes Grid from a MRC/CCP4 file."""
+        mrcfile = mrc.MRC(filename)
+        grid, edges = mrcfile.histogramdd()
+        self._load(grid=grid, edges=edges, metadata=self.metadata)
+        # Store header for access from Grid object (undocumented)
+        # https://github.com/MDAnalysis/GridDataFormats/pull/100#discussion_r782604833
+        self._mrc_header = mrcfile.header.copy()
 
     def _load_dx(self, filename):
         """Initializes Grid from a OpenDX file."""
         dx = OpenDX.field(0)
         dx.read(filename)
         grid, edges = dx.histogramdd()
-        self.__init__(grid=grid, edges=edges, metadata=self.metadata)
+        self._load(grid=grid, edges=edges, metadata=self.metadata)
 
     def _load_plt(self, filename):
         """Initialize Grid from gOpenMol plt file."""
         g = gOpenMol.Plt()
         g.read(filename)
         grid, edges = g.histogramdd()
-        self.__init__(grid=grid, edges=edges, metadata=self.metadata)
+        self._load(grid=grid, edges=edges, metadata=self.metadata)
 
     def export(self, filename, file_format=None, type=None, typequote='"'):
         """export density to file using the given format.
 
         The format can also be deduced from the suffix of the filename
-        though the *format* keyword takes precedence.
+        although the `file_format` keyword takes precedence.
 
-        The default format for export() is 'dx'.  Use 'dx' for
+        The default format for :meth:`export` is 'dx'.  Use 'dx' for
         visualization.
 
         Implemented formats:
@@ -465,7 +602,6 @@ class Grid(object):
 
         Parameters
         ----------
-
         filename : str
             name of the output file
 
@@ -501,7 +637,7 @@ class Grid(object):
         """Pickle the Grid object
 
         The object is dumped as a dictionary with grid and edges: This
-        is sufficient to recreate the grid object with __init__().
+        is sufficient to recreate the grid object with ``__init__()``.
         """
         data = dict(grid=self.grid, edges=self.edges, metadata=self.metadata)
         with open(filename, 'wb') as f:
@@ -526,8 +662,7 @@ class Grid(object):
             'File format: http://opendx.sdsc.edu/docs/html/pages/usrgu068.htm#HDREDF',
             'Data are embedded in the header and tied to the grid positions.',
             'Data is written in C array order: In grid[x,y,z] the axis z is fastest',
-            'varying, then y, then finally x, i.e. z is the innermost loop.'
-        ]
+            'varying, then y, then finally x, i.e. z is the innermost loop.']
 
         # write metadata in comments section
         if self.metadata:
@@ -544,10 +679,12 @@ class Grid(object):
             data=OpenDX.array(3, self.grid, type=type, typequote=typequote),
         )
         dx = OpenDX.field('density', components=components, comments=comments)
+        if ext == '.gz':
+            filename = root + ext
         dx.write(filename)
 
     def save(self, filename):
-        """Save a grid object to <filename>.pickle
+        """Save a grid object to `filename` and add ".pickle" extension.
 
         Internally, this calls
         ``Grid.export(filename, format="python")``. A grid can be
@@ -565,22 +702,46 @@ class Grid(object):
         self.export(filename, file_format="pickle")
 
     def centers(self):
-        """Returns the coordinates of the centers of all grid cells as an
-        iterator."""
+        """Returns the coordinates of the centers of all grid cells as an iterator.
+
+
+        See Also
+        --------
+        :func:`numpy.ndindex`
+        """
         for idx in numpy.ndindex(self.grid.shape):
             yield self.delta * numpy.array(idx) + self.origin
 
     def check_compatible(self, other):
-        """Check if *other* can be used in an arithmetic operation.
+        """Check if `other` can be used in an arithmetic operation.
 
-        1) *other* is a scalar
-        2) *other* is a grid defined on the same edges
+        `other` is compatible if
 
-        :Raises: :exc:`TypeError` if not compatible.
+        1) `other` is a scalar
+        2) `other` is a grid defined on the same edges
+
+        In order to make `other` compatible, resample it on the same
+        grid as this one using :meth:`resample`.
+
+        Parameters
+        ----------
+        other : Grid or float or int
+           Another object to be used for standard arithmetic
+           operations with this :class:`Grid`
+
+        Raises
+        ------
+        TypeError
+              if not compatible
+
+        See Also
+        --------
+        :meth:`resample`
         """
+
         if not (numpy.isreal(other) or self == other):
             raise TypeError(
-                "The argument can not be arithmetically combined with the grid. "
+                "The argument cannot be arithmetically combined with the grid. "
                 "It must be a scalar or a grid with identical edges. "
                 "Use Grid.resample(other.edges) to make a new grid that is "
                 "compatible with other.")
@@ -605,7 +766,8 @@ class Grid(object):
         import scipy.ndimage
 
         if spline_order is None:
-            # must be compatible with whatever :func:`scipy.ndimage.spline_filter` takes.
+            # must be compatible with whatever
+            # :func:`scipy.ndimage.spline_filter` takes.
             spline_order = self.interpolation_spline_order
         if cval is None:
             cval = self.interpolation_cval
@@ -641,18 +803,21 @@ class Grid(object):
             return scipy.ndimage.map_coordinates(coeffs,
                                                  _coordinates,
                                                  prefilter=False,
-                                                 mode='nearest',
+                                                 mode='constant',
                                                  cval=cval)
-        # mode='wrap' would be ideal but is broken: https://github.com/scipy/scipy/issues/1323
         return interpolatedF
 
     def __eq__(self, other):
         if not isinstance(other, Grid):
             return False
-        return numpy.all(other.grid == self.grid) and \
-            numpy.all(other.origin == self.origin) and \
-            numpy.all(numpy.all(other_edge == self_edge) for other_edge, self_edge in
-                      zip(other.edges, self.edges))
+        return numpy.all(
+            other.grid == self.grid) and numpy.all(
+            other.origin == self.origin) and numpy.all(
+            numpy.all(
+                other_edge == self_edge) for other_edge,
+            self_edge in zip(
+                other.edges,
+                self.edges))
 
     def __ne__(self, other):
         return not self.__eq__(other)
@@ -679,9 +844,13 @@ class Grid(object):
         # in Python 2 only (without __future__.division): will do "classic division"
         # https://docs.python.org/2/reference/datamodel.html#object.__div__
         if not six.PY2:
-            raise NotImplementedError("__div__ is only available in Python 2, use __truediv__")
+            raise NotImplementedError(
+                "__div__ is only available in Python 2, use __truediv__")
         self.check_compatible(other)
-        return self.__class__(self.grid.__div__(_grid(other)), edges=self.edges)
+        return self.__class__(
+            self.grid.__div__(
+                _grid(other)),
+            edges=self.edges)
 
     def __floordiv__(self, other):
         self.check_compatible(other)
@@ -689,7 +858,11 @@ class Grid(object):
 
     def __pow__(self, other):
         self.check_compatible(other)
-        return self.__class__(numpy.power(self.grid, _grid(other)), edges=self.edges)
+        return self.__class__(
+            numpy.power(
+                self.grid,
+                _grid(other)),
+            edges=self.edges)
 
     def __radd__(self, other):
         self.check_compatible(other)
@@ -711,9 +884,13 @@ class Grid(object):
         # in Python 2 only (without __future__.division): will do "classic division"
         # https://docs.python.org/2/reference/datamodel.html#object.__div__
         if not six.PY2:
-            raise NotImplementedError("__rdiv__ is only available in Python 2, use __rtruediv__")
+            raise NotImplementedError(
+                "__rdiv__ is only available in Python 2, use __rtruediv__")
         self.check_compatible(other)
-        return self.__class__(self.grid.__rdiv__(_grid(other)), edges=self.edges)
+        return self.__class__(
+            self.grid.__rdiv__(
+                _grid(other)),
+            edges=self.edges)
 
     def __rfloordiv__(self, other):
         self.check_compatible(other)
@@ -721,7 +898,11 @@ class Grid(object):
 
     def __rpow__(self, other):
         self.check_compatible(other)
-        return self.__class__(numpy.power(_grid(other), self.grid), edges=self.edges)
+        return self.__class__(
+            numpy.power(
+                _grid(other),
+                self.grid),
+            edges=self.edges)
 
     def __repr__(self):
         try:
@@ -744,7 +925,7 @@ def ndmeshgrid(*arrs):
 
     .. SeeAlso: :func:`numpy.meshgrid` for the 2D case.
     """
-    #arrs = tuple(reversed(arrs)) <-- wrong on stackoverflow.com
+    # arrs = tuple(reversed(arrs)) <-- wrong on stackoverflow.com
     arrs = tuple(arrs)
     lens = list(map(len, arrs))
     dim = len(arrs)
